==> moodle-1.4.3-pgsql.tgz: moodle/lang/ja_utf8/glossary.php <==
<?php // $Id$ 
      // glossary.php - created with Moodle 1.5 UNSTABLE DEVELOPMENT (2004121600)


$string['addcomment'] = 'コメントの追加';
$string['addentry'] = 'エントリの追加';
$string['addingcomment'] = 'コメントの追加';
$string['aliases'] = 'キーワード';
$string['allcategories'] = '全てのカテゴリ';
$string['allentries'] = '全て';
$string['allowcomments'] = 'エントリへのコメントを許可する';
$string['allowduplicatedentries'] = '重複エントリを許可する';
$string['allowratings'] = 'エントリの評価を許可しますか?';
$string['answer'] = '答え';
$string['approve'] = '承認';
$string['areyousuredelete'] = '本当にこのエントリを削除してもよろしいですか?';
$string['areyousuredeletecomment'] = '本当にこのコメントを削除してもよろしいですか?';
$string['areyousureexport'] = '本当にこのエントリを次へエクスポートしてもよろしいですか';
$string['ascending'] = '( 降順 )';
$string['attachment'] = '添付';
$string['authorview'] = '著者順に表示';
$string['back'] = '戻る';
$string['cantinsertcat'] = 'カテゴリを追加できません。';
$string['cantinsertrec'] = 'レコードを追加できません。';
$string['cantinsertrel'] = '関連カテゴリエントリを追加できません。';
$string['casesensitive'] = '大文字小文字の区別を行う';
$string['categories'] = 'カテゴリ';
$string['category'] = 'カテゴリ';
$string['categorydeleted'] = 'カテゴリが削除されました。';
$string['categoryview'] = 'カテゴリ順';
$string['cnfallowcomments'] = '用語集のエントリへのコメントをデフォルトで許可する。';
$string['cnfallowdupentries'] = '重複エントリを許可する。';
$string['cnfapprovalstatus'] = '学生による投稿を承認状態にする。';
$string['cnfcasesensitive'] = 'エントリがリンクの場合、大文字小文字の区別をする。';
$string['cnfdefaulthook'] = '用語集が表示される時のデフォルトセクションを選択してください。';
$string['cnfdefaultmode'] = '用語集が表示される時のデフォルトフレームを選択してください。';
$string['cnffullmatch'] = 'エントリがリンクの場合、ターゲットテキストと文字の大小(大文字・小文字)を合わせる。';
$string['cnflinkentry'] = 'エントリの自動的リンクを行う。';
$string['cnflinkglossaries'] = '自動リンクを行う。';
$string['cnfrelatedview'] = '自動リンク及びエントリ表示における表示形式を選択してください。';
$string['cnfshowgroup'] = 'グループ区切りを表示するか否か指定してください。';
$string['cnfsortkey'] = 'デフォルトの並び替えキーを選択してください。';
$string['cnfsortorder'] = 'デフォルトの並び替え順を選択してください。';
$string['cnfstudentcanpost'] = '学生の投稿を許可する。';
$string['comment'] = 'コメント';
$string['commentdeleted'] = 'コメントが削除されました。';
$string['comments'] = 'コメント';
$string['commentson'] = 'コメント';
$string['commentupdated'] = 'コメントが更新されました。';
$string['concept'] = '用語';
$string['concepts'] = '用語';
$string['configenablerssfeeds'] = 'このスイッチは用語集全てにおいてRSSフィードを設置可能にします。さらにそれぞれの用語集でRSSフィードを手動設定する必要があります。';
$string['currentglossary'] = '現在の用語集';
$string['dateview'] = '日付順';
$string['defaultapproval'] = 'デフォルトの承認状態';
$string['definition'] = '定義';
$string['definitions'] = '定義';
$string['deleteentry'] = 'エントリの削除';
$string['deletingcomment'] = 'コメントを削除しています。';
$string['deletingnoneemptycategory'] = '空でないカテゴリが削除された場合、関係するエントリも同時に削除されます。エントリを削除したい場合は、手動で行ってください。';
$string['descending'] = '( 昇順 )';
$string['destination'] = 'インポート先';
$string['displayformat'] = '表示フォーマット';
$string['displayformatcontinuous'] = '連続、著者無し';
$string['displayformatdictionary'] = 'シンプル、辞書スタイル';
$string['displayformatencyclopedia'] = '百科事典';
$string['displayformatentrylist'] = 'エントリリスト';
$string['displayformatfaq'] = 'FAQ';
$string['displayformatfullwithauthor'] = 'フル、著者有り';
$string['displayformatfullwithoutauthor'] = 'フル、著者無し';
$string['displayformats'] = '表示フォーマット';
$string['displayformatssetup'] = '表示フォーマット設定';
$string['duplicateentry'] = 'エントリを複写する';
$string['editalways'] = '常に編集を許可';
$string['editcategories'] = 'カテゴリの編集';
$string['editentry'] = 'エントリの編集';
$string['editingcomment'] = 'コメントの編集';
$string['entbypage'] = '1ページあたりの表示エントリ数';
$string['entries'] = 'エントリ';
$string['entrieswithoutcategory'] = 'カテゴリ無しのエントリ';
$string['entry'] = 'エントリ';
$string['entryalreadyexist'] = 'エントリが既に登録されています。';
$string['entryapproved'] = 'エントリが承認されました。';
$string['entrydeleted'] = 'エントリが削除されました。';
$string['entryexported'] = 'エントリが正常にエクスポートされました。';
$string['entryishidden'] = '( このエントリは現在非表示です )';
$string['entryleveldefaultsettings'] = 'エントリレベルデフォルト設定';
$string['entrysaved'] = 'エントリーが保存されました。';
$string['entryupdated'] = 'エントリーが更新されました。';
$string['entryusedynalink'] = 'エントリを自動的にリンクさせる';
$string['explainaddentry'] = '用語集に新しいエントリを追加します。<br />用語と定義は必須入力項目です。';
$string['explainall'] = '全てのエントリを1ページに表示';
$string['explainalphabet'] = 'インデックスを利用して用語集を表示';
$string['explainexport'] = 'ファイルが生成されました。<br />ファイルをダウンロードして安全に保管してください。いつでも必要な時に、このコースまたは他のコースにインポートすることができます。';
$string['explainimport'] = 'インポートするファイル及び処理方法を指定してください。<p>実行後、結果を検証してください。';
$string['explainspecial'] = '１文字で始まらないエントリを表示します。';
$string['exportedentry'] = 'エクスポートされたエントリ';
$string['exportedfile'] = 'エクスポートされたファイル';
$string['exportentries'] = 'エントリのエクスポート';
$string['exportglossary'] = '用語集のエクスポート';
$string['exporttomainglossary'] = 'メイン用語集のエクスポート';
$string['filetoimport'] = 'インポートするファイル';
$string['fillfields'] = '用語と定義は必須入力項目です。';
$string['filtername'] = '用語集オートリンク';
$string['fullmatch'] = '完全一致<small>（自動的にリンクさせる場合）</small>';
$string['globalglossary'] = 'グローバル用語集';
$string['glossaryleveldefaultsettings'] = '用語集レベルデフォルト設定';
$string['glossarytype'] = '用語集タイプ';
$string['glosssaryexported'] = '用語集がエクスポートされました。';
$string['importcategories'] = 'カテゴリをインポートする';
$string['importedcategories'] = 'インポートされたカテゴリ';
$string['importedentries'] = 'インポートされたエントリ';
$string['importentries'] = 'エントリのインポート';
$string['isglobal'] = 'この用語集はグローバルですか?';
$string['linkcategory'] = 'このカテゴリを自動的にリンクする';
$string['mainglossary'] = 'メイン用語集';
$string['maxtimehaspassed'] = '申し訳ございません、このコメントの最大編集回数($a)を超えました!';
$string['modulename'] = '用語集';
$string['modulenameplural'] = '用語集';
$string['newentries'] = '新しい用語集エントリ';
$string['newglossary'] = '新しい用語集';
$string['newglossarycreated'] = '新しい用語集が作成されました。';
$string['newglossaryentries'] = '新規用語集エントリ';
$string['nocomment'] = 'コメントが見つかりません';
$string['nocomments'] = '( このエントリにはコメントがありません )';
$string['noconceptfound'] = '用語または定義が見つかりませんでした。';
$string['noentries'] = 'このセクションにはエントリがありません。';
$string['noentry'] = 'エントリが見つかりませんでした。';
$string['notcategorised'] = 'カテゴリ無し';
$string['numberofentries'] = 'エントリ数';
$string['onebyline'] = '(1行あたり1件)';
$string['printerfriendly'] = '印刷形式';
$string['question'] = '質問';
$string['rate'] = '評価';
$string['rating'] = '評価';
$string['ratingeveryone'] = '誰でもエントリを評価できる';
$string['ratingno'] = '評価無し';
$string['ratingonlyteachers'] = '$a のみがエントリを評価できる';
$string['ratings'] = '評価';
$string['ratingssaved'] = '評価が保存されました';
$string['ratingsuse'] = '評価を使用する';
$string['ratingtime'] = 'エントリ評価を下記の期間に制限する:';
$string['rejectedentries'] = '拒否されたエントリ';
$string['rejectionrpt'] = '拒否レポート';
$string['rsssubscriberss'] = '\'$a\' 用語のRSSフィードを表示';
$string['searchindefinition'] = '定義も検索する';
$string['secondaryglossary'] = 'サブ用語集';
$string['sendinratings'] = '最新の評価を送る';
$string['showall'] = '全てのリンクを表示';
$string['showalphabet'] = 'アルファベットを表示';
$string['showspecial'] = '特別リンクを表示';
$string['sortby'] = '並び替え';
$string['sortbycreation'] = '作成日時';
$string['sortbylastupdate'] = '最終更新日時';
$string['sortchronogically'] = '日付順の並び替え';
$string['special'] = '特別';
$string['standardview'] = 'アルファベット順';
$string['studentcanpost'] = '学生のエントリ追加を許可する';
$string['totalentries'] = 'エントリ合計';
$string['usedynalink'] = 'エントリを自動的にリンクする';
$string['waitingapproval'] = '承認待ち';
$string['warningstudentcapost'] = '( 用語集がメインで無い場合に適用 )';
$string['withauthor'] = '用語 ( 著者有り )';
$string['withoutauthor'] = '用語 ( 著者無し )';
$string['writtenby'] = '作成';
$string['youarenottheauthor'] = 'あなたはこのコメントの作者ではありません。編集はできません。';

?>

==> moodle-1.5-pgsql.tgz: moodle/lang/ja_utf8/glossary.php <==
<?php // $Id$ 
      // glossary.php - created with Moodle 1.5 UNSTABLE DEVELOPMENT (2005011000)


$string['addcomment'] = 'コメントの追加';
$string['addentry'] = 'エントリの追加';
$string['addingcomment'] = 'コメントの追加';
$string['aliases'] = 'キーワード';
$string['allcategories'] = '全てのカテゴリ';
$string['allentries'] = '全て';
$string['allowcomments'] = 'エントリへのコメントを許可する';
$string['allowduplicatedentries'] = '重複エントリを許可する';
$string['allowprintview'] = '印刷モードを許可する';
$string['allowratings'] = 'エントリの評価を許可しますか?';
$string['answer'] = '答え';
$string['approve'] = '承認';
$string['areyousuredelete'] = '本当にこのエントリを削除してもよろしいですか?';
$string['areyousuredeletecomment'] = '本当にこのコメントを削除してもよろしいですか?';
$string['areyousureexport'] = '本当にこのエントリを次へエクスポートしてもよろしいですか';
$string['ascending'] = '( 降順 )';
$string['attachment'] = '添付';
$string['authorview'] = '著者順に表示';
$string['back'] = '戻る';
$string['cantinsertcat'] = 'カテゴリを追加できません。';
$string['cantinsertrec'] = 'レコードを追加できません。';
$string['cantinsertrel'] = '関連カテゴリエントリを追加できません。';
$string['casesensitive'] = '大文字小文字の区別を行う';
$string['categories'] = 'カテゴリ';
$string['category'] = 'カテゴリ';
$string['categorydeleted'] = 'カテゴリが削除されました。';
$string['categoryview'] = 'カテゴリ順';
$string['cnfallowcomments'] = '用語集のエントリへのコメントをデフォルトで許可する。';
$string['cnfallowdupentries'] = '重複エントリを許可する。';
$string['cnfapprovalstatus'] = '学生による投稿を承認状態にする。';
$string['cnfcasesensitive'] = 'エントリがリンクの場合、大文字小文字の区別をする。';
$string['cnfdefaulthook'] = '用語集が表示される時のデフォルトセクションを選択してください。';
$string['cnfdefaultmode'] = '用語集が表示される時のデフォルトフレームを選択してください。';
$string['cnffullmatch'] = 'エントリがリンクの場合、ターゲットテキストと文字の大小(大文字・小文字)を合わせる。';
$string['cnflinkentry'] = 'エントリの自動的リンクを行う。';
$string['cnflinkglossaries'] = '自動リンクを行う。';
$string['cnfrelatedview'] = '自動リンクおよびエントリ表示における表示形式を選択してください。';
$string['cnfshowgroup'] = 'グループ区切りを表示するか否か指定してください。';
$string['cnfsortkey'] = 'デフォルトの並び替えキーを選択してください。';
$string['cnfsortorder'] = 'デフォルトの並び替え順を選択してください。';
$string['cnfstudentcanpost'] = '学生の投稿を許可する。';
$string['comment'] = 'コメント';
$string['commentdeleted'] = 'コメントが削除されました。';
$string['comments'] = 'コメント';
$string['commentson'] = 'コメント';
$string['commentupdated'] = 'コメントが更新されました。';
$string['concept'] = '用語';
$string['concepts'] = '用語';
$string['configenablerssfeeds'] = 'このスイッチは用語集全てにおいてRSSフィードを設置可能にします。さらにそれぞれの用語集でRSSフィードを手動設定する必要があります。';
$string['currentglossary'] = '現在の用語集';
$string['dateview'] = '日付順';
$string['defaultapproval'] = 'デフォルトの承認状態';
$string['definition'] = '定義';
$string['definitions'] = '定義';
$string['deleteentry'] = 'エントリの削除';
$string['deletingcomment'] = 'コメントを削除しています。';
$string['deletingnoneemptycategory'] = '空でないカテゴリが削除された場合、関係するエントリも同時に削除されます。エントリを削除したい場合は、手動で行ってください。';
$string['descending'] = '( 昇順 )';
$string['destination'] = 'インポート先';
$string['displayformat'] = '表示フォーマット';
$string['displayformatcontinuous'] = '連続、著者無し';
$string['displayformatdictionary'] = 'シンプル、辞書スタイル';
$string['displayformatencyclopedia'] = '百科事典';
$string['displayformatentrylist'] = 'エントリリスト';
$string['displayformatfaq'] = 'FAQ';
$string['displayformatfullwithauthor'] = 'フル、著者有り';
$string['displayformatfullwithoutauthor'] = 'フル、著者無し';
$string['displayformats'] = '表示フォーマット';
$string['displayformatssetup'] = '表示フォーマット設定';
$string['duplicateentry'] = 'エントリを複写する';
$string['editalways'] = '常に編集を許可';
$string['editcategories'] = 'カテゴリの編集';
$string['editentry'] = 'エントリの編集';
$string['editingcomment'] = 'コメントの編集';
$string['entbypage'] = '1ページあたりの表示エントリ数';
$string['entries'] = 'エントリ';
$string['entrieswithoutcategory'] = 'カテゴリ無しのエントリ';
$string['entry'] = 'エントリ';
$string['entryalreadyexist'] = 'エントリが既に登録されています。';
$string['entryapproved'] = 'エントリが承認されました。';
$string['entrydeleted'] = 'エントリが削除されました。';
$string['entryexported'] = 'エントリが正常にエクスポートされました。';
$string['entryishidden'] = '( このエントリは現在非表示です )';
$string['entryleveldefaultsettings'] = 'エントリレベルデフォルト設定';
$string['entrysaved'] = 'エントリーが保存されました。';
$string['entryupdated'] = 'エントリーが更新されました。';
$string['entryusedynalink'] = 'エントリを自動的にリンクさせる';
$string['explainaddentry'] = '用語集に新しいエントリを追加します。<br />用語と定義は必須入力項目です。';
$string['explainall'] = '全てのエントリを1ページに表示';
$string['explainalphabet'] = 'インデックスを利用して用語集を表示';
$string['explainexport'] = 'ファイルが生成されました。<br />ファイルをダウンロードして安全に保管してください。いつでも必要な時に、このコースまたは他のコースにインポートすることができます。';
$string['explainimport'] = 'インポートするファイルおよび処理方法を指定してください。<p>実行後、結果を検証してください。';
$string['explainspecial'] = '１文字で始まらないエントリを表示します。';
$string['exportedentry'] = 'エクスポートされたエントリ';
$string['exportedfile'] = 'エクスポートされたファイル';
$string['exportentries'] = 'エントリのエクスポート';
$string['exportglossary'] = '用語集のエクスポート';
$string['exporttomainglossary'] = 'メイン用語集のエクスポート';
$string['filetoimport'] = 'インポートするファイル';
$string['fillfields'] = '用語と定義は必須入力項目です。';
$string['filtername'] = '用語集オートリンク';
$string['fullmatch'] = '完全一致<small>（自動的にリンクさせる場合）</small>';
$string['globalglossary'] = 'グローバル用語集';
$string['glossaryleveldefaultsettings'] = '用語集レベルデフォルト設定';
$string['glossarytype'] = '用語集タイプ';
$string['glosssaryexported'] = '用語集がエクスポートされました。';
$string['importcategories'] = 'カテゴリをインポートする';
$string['importedcategories'] = 'インポートされたカテゴリ';
$string['importedentries'] = 'インポートされたエントリ';
$string['importentries'] = 'エントリのインポート';
$string['isglobal'] = 'この用語集はグローバルですか?';
$string['linkcategory'] = 'このカテゴリを自動的にリンクする';
$string['mainglossary'] = 'メイン用語集';
$string['maxtimehaspassed'] = '申し訳ございません、このコメントの最大編集回数($a)を超えました!';
$string['modulename'] = '用語集';
$string['modulenameplural'] = '用語集';
$string['newentries'] = '新しい用語集エントリ';
$string['newglossary'] = '新しい用語集';
$string['newglossarycreated'] = '新しい用語集が作成されました。';
$string['newglossaryentries'] = '新規用語集エントリ';
$string['nocomment'] = 'コメントが見つかりません';
$string['nocomments'] = '( このエントリにはコメントがありません )';
$string['noconceptfound'] = '用語または定義が見つかりませんでした。';
$string['noentries'] = 'このセクションにはエントリがありません。';
$string['noentry'] = 'エントリが見つかりませんでした。';
$string['notcategorised'] = 'カテゴリ無し';
$string['numberofentries'] = 'エントリ数';
$string['onebyline'] = '(1行あたり1件)';
$string['printerfriendly'] = '印刷モード';
$string['printviewnotallowed'] = '印刷モードは許可されていません。';
$string['question'] = '質問';
$string['rate'] = '評価';
$string['rating'] = '評価';
$string['ratingeveryone'] = '誰でもエントリを評価できる';
$string['ratingno'] = '評価無し';
$string['ratingonlyteachers'] = '$a のみがエントリを評価できる';
$string['ratings'] = '評価';
$string['ratingssaved'] = '評価が保存されました';
$string['ratingsuse'] = '評価を使用する';
$string['ratingtime'] = 'エントリ評価を下記の期間に制限する:';
$string['rejectedentries'] = '拒否されたエントリ';
$string['rejectionrpt'] = '拒否レポート';
$string['rsssubscriberss'] = '\'$a\' 用語のRSSフィードを表示';
$string['searchindefinition'] = '定義も検索する';
$string['secondaryglossary'] = 'サブ用語集';
$string['sendinratings'] = '最新の評価を送る';
$string['showall'] = '全てのリンクを表示';
$string['showalphabet'] = 'アルファベットを表示';
$string['showspecial'] = '特別リンクを表示';
$string['sortby'] = '並び替え';
$string['sortbycreation'] = '作成日時';
$string['sortbylastupdate'] = '最終更新日時';
$string['sortchronogically'] = '日付順の並び替え';
$string['special'] = '特別';
$string['standardview'] = 'アルファベット順';
$string['studentcanpost'] = '学生のエントリ追加を許可する';
$string['totalentries'] = 'エントリ合計';
$string['usedynalink'] = 'エントリを自動的にリンクする';
$string['waitingapproval'] = '承認待ち';
$string['warningstudentcapost'] = '( 用語集がメインで無い場合に適用 )';
$string['withauthor'] = '用語 ( 著者有り )';
$string['withoutauthor'] = '用語 ( 著者無し )';
$string['writtenby'] = '作成';
$string['youarenottheauthor'] = 'あなたはこのコメントの作者ではありません。編集はできません。';

?>
